summaryrefslogtreecommitdiff
path: root/kc/core/panic.c
diff options
context:
space:
mode:
authorAda Christine <adachristine18@gmail.com>2026-05-24 11:09:31 +0000
committerAda Christine <adachristine18@gmail.com>2026-05-24 11:09:31 +0000
commitd07bd08dd0446e8c41eccaccbb07e9112200e8ee (patch)
tree742a3f9d9d84c8ee55858b2ebc7e0e0f8c714c7c /kc/core/panic.c
parent9aaf21bf10d00ec12b24499817e3e91dca08c461 (diff)
rename and move, function renames in stdio
Diffstat (limited to 'kc/core/panic.c')
-rw-r--r--kc/core/panic.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/kc/core/panic.c b/kc/core/panic.c
index 7844487..02c58c7 100644
--- a/kc/core/panic.c
+++ b/kc/core/panic.c
@@ -1,6 +1,6 @@
#include "panic.h"
-#include <lib/kstdio.h>
+#include <libc/stdio.h>
#include <stdbool.h>
@@ -13,12 +13,12 @@ static char const *reason_strings[] = {
noreturn void panic(const char *file, int line, enum panic_reason reason)
{
// TODO: kprintf() and friends
if (reason > sizeof(reason_strings) / sizeof(*reason_strings))
{
reason = 0;
}
- kprintf(
+ printf(
"kernel panic:%s:%u %s\n",
file,
line,
@@ -13,12 +13,12 @@ static char const *reason_strings[] = {
noreturn void panic(const char *file, int line, enum panic_reason reason)
{
- // TODO: kprintf() and friends
+ // TODO: printf() and friends
if (reason > sizeof(reason_strings) / sizeof(*reason_strings))
{